"""
* Author: "PeppermintOS Team(peppermintosteam@proton.me)
*
* License: SPDX-License-Identifier: GPL-3.0-or-later
*
* Build the ISOs for the the system
"""
import os
from pathlib import Path
import argparse
import collections
import conf
import infra
import inflate_bubble
import finish_cleanup

# Set the home path used regardless the user logged in
BSTRING_ISO_CONFIGS = '~/bubbles/iso_configs'
HOME_FOLDER = str(Path(BSTRING_ISO_CONFIGS).expanduser())
FUSATO_ROOT = '/fusato'
WPCHROOT = '/fusato/config/includes.chroot'
term_size = os.get_terminal_size()


class BuildXfce:
    """
    Determine what base to use and then build the ISO
    """
    def __init__(self, sbase, sarch):
        self.sbase = sbase
        self.sarch = sarch
        os.chdir(HOME_FOLDER + FUSATO_ROOT)
        # Determine what base to build
        if sbase == "deb":
            # Run the Debian Build
            self.debian_build()
        elif sbase == "dev":
            self.devuan_build()
        else:
            print("No base has been found")


    def build_deb_64(self):
        """ Builds the 64bit ISO XFCE"""
        current_working_directory = os.getcwd()
        print('=' * term_size.columns)
        print("INFO: Building a Debian based 64 bit ISO")
        print("INFO: Current working directory" +
               current_working_directory
               )
        print('=' * term_size.columns)
        # Set the config tree
        lbsetup = conf.lbset_deb64
        os.system(lbsetup)
        print("Config tree ready!")
        # Start with the XFCE stuff
        cmd_list_64 = collections.deque(conf.build64_xfce_build)
        list_size_64 = len(cmd_list_64)
        for _ in range(list_size_64):
            i = cmd_list_64.popleft()
            execute = i + '()'
            exec(execute)
        # Run the specific classes
        infra.ChrootFolders("deb", "_64")
        infra.BinaryFolders("deb", "_64")
        infra.ArchitectureFiles("deb", "_64")
        # Run the Build
        print('=' * term_size.columns)
        print("INFO: Configs in place start the ISO build process")
        print("INFO: Start Live-Build Process")
        print("INFO: Current working directory" +
               current_working_directory
               )
        print('.' * term_size.columns)
        lbsetup = conf.lbset_deb64
        os.system(lbsetup)
        run_cmd = 'sudo lb build'
        current_working_directory = os.getcwd()
        os.chdir(HOME_FOLDER + FUSATO_ROOT)
        print("INFO: Current working directory" +
              current_working_directory
              )
        os.system(run_cmd)
        print("INFO: ISO build has completed successfully")
        print('.' * term_size.columns)
        print("INFO: Current working directory" +
              current_working_directory
              )
        print('=' * term_size.columns)
        finish_cleanup.make_check_sum()
        finish_cleanup.copy_iso_file_nightly_deb64()
        finish_cleanup.kill_old_iso()
        print('=' * term_size.columns)
        print("INFO: ISO is ready for usage.")
        print('=' * term_size.columns)


    def build_deb_32(self):
        """ Builds the 32bit ISO XFCE"""
        current_working_directory = os.getcwd()
        print('=' * term_size.columns)
        print("INFO: Building a Debian based 32 bit ISO")
        print("INFO: Current working directory" +
               current_working_directory
               )
        print('=' * term_size.columns)
        # Set the config tree
        lbsetup = conf.lbset_deb32
        os.system(lbsetup)
        print("Config tree ready!")
        # Start with the XFCE stuff
        cmd_list_32 = collections.deque(conf.build32_xfce_build)
        list_size_32 = len(cmd_list_32)
        for _ in range(list_size_32):
            i = cmd_list_32.popleft()
            execute = i + '()'
            exec(execute)
        # Run the specific classes
        infra.ChrootFolders("deb", "_32")
        infra.BinaryFolders("deb", "_32")
        infra.ArchitectureFiles("deb", "_32")
        # Run the Build
        print('=' * term_size.columns)
        print("INFO: Configs in place start the ISO build process")
        print("INFO: Start Live-Build Process")
        print("INFO: Current working directory" +
               current_working_directory
               )
        print('.' * term_size.columns)
        lbsetup = conf.lbset_deb32
        os.system(lbsetup)
        run_cmd = 'sudo lb build'
        current_working_directory = os.getcwd()
        os.chdir(HOME_FOLDER + FUSATO_ROOT)
        print("INFO: Current working directory" +
             current_working_directory
              )
        os.system(run_cmd)
        print("INFO: ISO build has completed successfully")
        print('.' * term_size.columns)
        print("INFO: Current working directory" +
             current_working_directory
              )
        print('=' * term_size.columns)
        finish_cleanup.make_check_sum()
        finish_cleanup.copy_iso_file_nightly_deb32()
        finish_cleanup.kill_old_iso()
        print('=' * term_size.columns)
        print("INFO: ISO is ready for usage.")
        print('=' * term_size.columns)


    def build_deb_arm(self):
        """ Builds the arm ISO XFCE"""
        current_working_directory = os.getcwd()
        print('=' * term_size.columns)
        print("INFO: Building a Debian based arm bit ISO")
        print("INFO: Current working directory" +
               current_working_directory
               )
        print('=' * term_size.columns)
        # Set the config tree
        lbsetup = conf.lbset_debarm
        os.system(lbsetup)
        print("Config tree ready!")
        # Start with the XFCE stuff
        cmd_list_arm = collections.deque(conf.buildarm_xfce_build)
        list_size_arm = len(cmd_list_arm)
        for _ in range(list_size_arm):
            i = cmd_list_arm.popleft()
            execute = i + '()'
            exec(execute)
        # Run the specific classes
        infra.ChrootFolders("deb", "_arm")
        infra.BinaryFolders("deb", "_arm")
        infra.ArchitectureFiles("deb", "_arm")
        # Run the Build
        print('=' * term_size.columns)
        print("INFO: Configs in place start the ISO build process")
        print("INFO: Start Live-Build Process")
        print("INFO: Current working directory" +
              current_working_directory
               )
        print('.' * term_size.columns)
        lbsetup = conf.lbset_debarm
        os.system(lbsetup)
        run_cmd = 'sudo lb build'
        current_working_directory = os.getcwd()
        os.chdir(HOME_FOLDER + FUSATO_ROOT)
        print("INFO: Current working directory" +
              current_working_directory
              )
        os.system(run_cmd)
        print("INFO: ISO build has completed successfully")
        print('.' * term_size.columns)
        print("INFO: Current working directory" +
               current_working_directory
               )
        print('=' * term_size.columns)
        finish_cleanup.make_check_sum()
        finish_cleanup.copy_iso_file_nightly_debarm()
        finish_cleanup.kill_old_iso()
        print('=' * term_size.columns)
        print("INFO: ISO is ready for usage.")
        print('=' * term_size.columns)


    def debian_build(self):
        """
        Used to build the Debian base XFCE ISO
        """
        if self.sarch == '_64':
            self.build_deb_64()
        elif self.sarch == '_32':
            self.build_deb_32()
        elif self.sarch == '_arm':
            self.build_deb_arm()
        else:
            print("WARNING: No active build specified")


    def build_dev_64(self):
        """ Builds the 64bit ISO XFCE"""
        current_working_directory = os.getcwd()
        print('=' * term_size.columns)
        print("INFO: Building a devuan based 64 bit ISO")
        print("INFO: Current working directory" +
               current_working_directory
               )
        print('=' * term_size.columns)
        # Set the config tree
        lbsetup = conf.lbset_dev64
        os.system(lbsetup)
        print("Config tree ready!")
        # Start with the XFCE stuff
        cmd_list_64 = collections.deque(conf.build64_xfce_build)
        list_size_64 = len(cmd_list_64)
        for _ in range(list_size_64):
            i = cmd_list_64.popleft()
            execute = i + '()'
            exec(execute)
        # Run the specific classes
        infra.ChrootFolders("dev", "_64")
        infra.BinaryFolders("dev", "_64")
        infra.ArchitectureFiles("dev", "_64")
        # Run the Build
        print('=' * term_size.columns)
        print("INFO: Configs in place start the ISO build process")
        print("INFO: Start Live-Build Process")
        print("INFO: Current working directory" +
              current_working_directory
              )
        print('.' * term_size.columns)
        lbsetup = conf.lbset_dev64
        os.system(lbsetup)
        run_cmd = 'sudo lb build'
        current_working_directory = os.getcwd()
        os.chdir(HOME_FOLDER + FUSATO_ROOT)
        print("INFO: Current working directory" +
              current_working_directory
              )
        os.system(run_cmd)
        print("INFO: ISO build has completed successfully")
        print('.' * term_size.columns)
        print("INFO: Current working directory" +
              current_working_directory
              )
        print('=' * term_size.columns)
        finish_cleanup.make_check_sum()
        finish_cleanup.copy_iso_file_nightly_dev64()
        finish_cleanup.kill_old_iso()
        #'finish_cleanup.copy_iso_file_prod_deb64',
        print('=' * term_size.columns)
        print("INFO: ISO is ready for usage.")
        print('=' * term_size.columns)


    def build_dev_32(self):
        """ Builds the 32bit ISO XFCE"""
        current_working_directory = os.getcwd()
        print('=' * term_size.columns)
        print("INFO: Building a devuan based 32 bit ISO")
        print("INFO: Current working directory" +
               current_working_directory
               )
        print('=' * term_size.columns)
        # Set the config tree
        lbsetup = conf.lbset_dev32
        os.system(lbsetup)
        print("Config tree ready!")
        # Start with the XFCE stuff
        cmd_list_32 = collections.deque(conf.build32_xfce_build)
        list_size_32 = len(cmd_list_32)
        for _ in range(list_size_32):
            i = cmd_list_32.popleft()
            execute = i + '()'
            exec(execute)
        # Run the specific classes
        infra.ChrootFolders("dev", "_32")
        infra.BinaryFolders("dev", "_32")
        infra.ArchitectureFiles("dev", "_32")
        # Run the Build
        print('=' * term_size.columns)
        print("INFO: Configs in place start the ISO build process")
        print("INFO: Start Live-Build Process")
        print("INFO: Current working directory" +
               current_working_directory
               )
        print('.' * term_size.columns)
        lbsetup = conf.lbset_dev32
        os.system(lbsetup)
        run_cmd = 'sudo lb build'
        current_working_directory = os.getcwd()
        os.chdir(HOME_FOLDER + FUSATO_ROOT)
        print("INFO: Current working directory" +
              current_working_directory
              )
        os.system(run_cmd)
        print("INFO: ISO build has completed successfully")
        print('.' * term_size.columns)
        print("INFO: Current working directory" +
              current_working_directory
              )
        print('=' * term_size.columns)
        finish_cleanup.make_check_sum()
        finish_cleanup.copy_iso_file_nightly_dev32()
        finish_cleanup.kill_old_iso()
        print('=' * term_size.columns)
        print("INFO: ISO is ready for usage.")
        print('=' * term_size.columns)


    def build_dev_arm(self):
        """ Builds the arm ISO XFCE"""
        current_working_directory = os.getcwd()
        print('=' * term_size.columns)
        print("INFO: Building a devuan based arm bit ISO")
        print("INFO: Current working directory" +
               current_working_directory
               )
        print('=' * term_size.columns)
        # Set the config tree
        lbsetup = conf.lbset_devarm
        os.system(lbsetup)
        print("Config tree ready!")
        # Start with the XFCE stuff
        cmd_list_arm = collections.deque(conf.buildarm_xfce_build)
        list_size_arm = len(cmd_list_arm)
        for _ in range(list_size_arm):
            i = cmd_list_arm.popleft()
            execute = i + '()'
            exec(execute)
        # Run the specific classes
        infra.ChrootFolders("dev", "_arm")
        infra.BinaryFolders("dev", "_arm")
        infra.ArchitectureFiles("dev", "_arm")
        # Run the Build
        print('=' * term_size.columns)
        print("INFO: Configs in place start the ISO build process")
        print("INFO: Start Live-Build Process")
        print("INFO: Current working directory" +
               current_working_directory
               )
        print('.' * term_size.columns)
        lbsetup = conf.lbset_devarm
        os.system(lbsetup)
        run_cmd = 'sudo lb build'
        current_working_directory = os.getcwd()
        os.chdir(HOME_FOLDER + FUSATO_ROOT)
        print("INFO: Current working directory" +
              current_working_directory
              )
        os.system(run_cmd)
        print("INFO: ISO build has completed successfully")
        print('.' * term_size.columns)
        print("INFO: Current working directory" +
              current_working_directory
              )
        print('=' * term_size.columns)
        finish_cleanup.make_check_sum()
        finish_cleanup.copy_iso_file_nightly_devarm()
        finish_cleanup.kill_old_iso()
        print('=' * term_size.columns)
        print("INFO: ISO is ready for usage.")
        print('=' * term_size.columns)


    def devuan_build(self):
        """
        Used to build the devuan base XFCE ISO
        """
        if self.sarch == '_64':
            self.build_dev_64()
        elif self.sarch == '_32':
            self.build_dev_32()
        elif self.sarch == '_arm':
            self.build_dev_arm()
        else:
            print("WARNING: No active build specified")


class BuildGflashback:
    """
    Determine what base to use and then build the ISO
    """
    def __init__(self, sbase, sarch):
        self.sbase = sbase
        self.sarch = sarch
        os.chdir(HOME_FOLDER + FUSATO_ROOT)
        # Determine what base to build
        if sbase == "deb":
            # Run the Debian Build
            self.debian_build()
        elif sbase == "dev":
            self.devuan_build()
        else:
            print("No base has been found")


    def build_deb_64(self):
        """ Builds the 64bit ISO GNOME FlashBack"""
        current_working_directory = os.getcwd()
        print('=' * term_size.columns)
        print("INFO: Building a Debian based 64 bit ISO")
        print("INFO: Current working directory" +
               current_working_directory
               )
        print('=' * term_size.columns)
        # Set the config tree
        lbsetup = conf.lbset_deb64
        os.system(lbsetup)
        print("Config tree ready!")
        # Start with the GNOME FlashBack stuff
        cmd_list_64 = collections.deque(conf.build64_gfb_build)
        list_size_64 = len(cmd_list_64)
        for _ in range(list_size_64):
            i = cmd_list_64.popleft()
            execute = i + '()'
            exec(execute)
        # Run the specific classes
        infra.ChrootFolders("deb", "_64")
        infra.BinaryFolders("deb", "_64")
        infra.ArchitectureFiles("deb", "_64")
        # Run the Build
        print('=' * term_size.columns)
        print("INFO: Configs in place start the ISO build process")
        print("INFO: Start Live-Build Process")
        print("INFO: Current working directory" +
               current_working_directory
               )
        print('.' * term_size.columns)
        lbsetup = conf.lbset_deb64
        os.system(lbsetup)
        run_cmd = 'sudo lb build'
        current_working_directory = os.getcwd()
        os.chdir(HOME_FOLDER + FUSATO_ROOT)
        print("INFO: Current working directory" +
              current_working_directory
              )
        os.system(run_cmd)
        print("INFO: ISO build has completed successfully")
        print('.' * term_size.columns)
        print("INFO: Current working directory" +
              current_working_directory
              )
        print('=' * term_size.columns)
        finish_cleanup.make_check_sum()
        finish_cleanup.copy_iso_file_nightly_deb64()
        finish_cleanup.kill_old_iso()
        print('=' * term_size.columns)
        print("INFO: ISO is ready for usage.")
        print('=' * term_size.columns)


    def build_deb_32(self):
        """ Builds the 32bit ISO GNOME FlashBack"""
        current_working_directory = os.getcwd()
        print('=' * term_size.columns)
        print("INFO: Building a Debian based 32 bit ISO")
        print("INFO: Current working directory" +
               current_working_directory
               )
        print('=' * term_size.columns)
        # Set the config tree
        lbsetup = conf.lbset_deb32
        os.system(lbsetup)
        print("Config tree ready!")
        # Start with the GNOME FlashBack stuff
        cmd_list_32 = collections.deque(conf.build32_gfb_build)
        list_size_32 = len(cmd_list_32)
        for _ in range(list_size_32):
            i = cmd_list_32.popleft()
            execute = i + '()'
            exec(execute)
        # Run the specific classes
        infra.ChrootFolders("deb", "_32")
        infra.BinaryFolders("deb", "_32")
        infra.ArchitectureFiles("deb", "_32")
        # Run the Build
        print('=' * term_size.columns)
        print("INFO: Configs in place start the ISO build process")
        print("INFO: Start Live-Build Process")
        print("INFO: Current working directory" +
               current_working_directory
               )
        print('.' * term_size.columns)
        lbsetup = conf.lbset_deb32
        os.system(lbsetup)
        run_cmd = 'sudo lb build'
        current_working_directory = os.getcwd()
        os.chdir(HOME_FOLDER + FUSATO_ROOT)
        print("INFO: Current working directory" +
             current_working_directory
              )
        os.system(run_cmd)
        print("INFO: ISO build has completed successfully")
        print('.' * term_size.columns)
        print("INFO: Current working directory" +
             current_working_directory
              )
        print('=' * term_size.columns)
        finish_cleanup.make_check_sum()
        finish_cleanup.copy_iso_file_nightly_deb32()
        finish_cleanup.kill_old_iso()
        print('=' * term_size.columns)
        print("INFO: ISO is ready for usage.")
        print('=' * term_size.columns)


    def build_deb_arm(self):
        """ Builds the arm ISO GNOME FlashBack"""
        current_working_directory = os.getcwd()
        print('=' * term_size.columns)
        print("INFO: Building a Debian based arm bit ISO")
        print("INFO: Current working directory" +
               current_working_directory
               )
        print('=' * term_size.columns)
        # Set the config tree
        lbsetup = conf.lbset_debarm
        os.system(lbsetup)
        print("Config tree ready!")
        # Start with the GNOME FlashBack stuff
        cmd_list_arm = collections.deque(conf.buildarm_gfb_build)
        list_size_arm = len(cmd_list_arm)
        for _ in range(list_size_arm):
            i = cmd_list_arm.popleft()
            execute = i + '()'
            exec(execute)
        # Run the specific classes
        infra.ChrootFolders("deb", "_arm")
        infra.BinaryFolders("deb", "_arm")
        infra.ArchitectureFiles("deb", "_arm")
        # Run the Build
        print('=' * term_size.columns)
        print("INFO: Configs in place start the ISO build process")
        print("INFO: Start Live-Build Process")
        print("INFO: Current working directory" +
              current_working_directory
               )
        print('.' * term_size.columns)
        lbsetup = conf.lbset_debarm
        os.system(lbsetup)
        run_cmd = 'sudo lb build'
        current_working_directory = os.getcwd()
        os.chdir(HOME_FOLDER + FUSATO_ROOT)
        print("INFO: Current working directory" +
              current_working_directory
              )
        os.system(run_cmd)
        print("INFO: ISO build has completed successfully")
        print('.' * term_size.columns)
        print("INFO: Current working directory" +
               current_working_directory
               )
        print('=' * term_size.columns)
        finish_cleanup.make_check_sum()
        finish_cleanup.copy_iso_file_nightly_debarm()
        finish_cleanup.kill_old_iso()
        print('=' * term_size.columns)
        print("INFO: ISO is ready for usage.")
        print('=' * term_size.columns)


    def debian_build(self):
        """
        Used to build the Debian base GNOME FlashBack ISO
        """
        if self.sarch == '_64':
            self.build_deb_64()
        elif self.sarch == '_32':
            self.build_deb_32()
        elif self.sarch == '_arm':
            self.build_deb_arm()
        else:
            print("WARNING: No active build specified")


    def build_dev_64(self):
        """ Builds the 64bit ISO GNOME FlashBack"""
        current_working_directory = os.getcwd()
        print('=' * term_size.columns)
        print("INFO: Building a devuan based 64 bit ISO")
        print("INFO: Current working directory" +
               current_working_directory
               )
        print('=' * term_size.columns)
        # Set the config tree
        lbsetup = conf.lbset_dev64
        os.system(lbsetup)
        print("Config tree ready!")
        # Start with the GNOME FlashBack stuff
        cmd_list_64 = collections.deque(conf.build64_gfb_build)
        list_size_64 = len(cmd_list_64)
        for _ in range(list_size_64):
            i = cmd_list_64.popleft()
            execute = i + '()'
            exec(execute)
        # Run the specific classes
        infra.ChrootFolders("dev", "_64")
        infra.BinaryFolders("dev", "_64")
        infra.ArchitectureFiles("dev", "_64")
        # Run the Build
        print('=' * term_size.columns)
        print("INFO: Configs in place start the ISO build process")
        print("INFO: Start Live-Build Process")
        print("INFO: Current working directory" +
              current_working_directory
              )
        print('.' * term_size.columns)
        lbsetup = conf.lbset_dev64
        os.system(lbsetup)
        run_cmd = 'sudo lb build'
        current_working_directory = os.getcwd()
        os.chdir(HOME_FOLDER + FUSATO_ROOT)
        print("INFO: Current working directory" +
              current_working_directory
              )
        os.system(run_cmd)
        print("INFO: ISO build has completed successfully")
        print('.' * term_size.columns)
        print("INFO: Current working directory" +
              current_working_directory
              )
        print('=' * term_size.columns)
        finish_cleanup.make_check_sum()
        finish_cleanup.copy_iso_file_nightly_dev64()
        finish_cleanup.kill_old_iso()
        #'finish_cleanup.copy_iso_file_prod_deb64',
        print('=' * term_size.columns)
        print("INFO: ISO is ready for usage.")
        print('=' * term_size.columns)


    def build_dev_32(self):
        """ Builds the 32bit ISO GNOME FlashBack"""
        current_working_directory = os.getcwd()
        print('=' * term_size.columns)
        print("INFO: Building a devuan based 32 bit ISO")
        print("INFO: Current working directory" +
               current_working_directory
               )
        print('=' * term_size.columns)
        # Set the config tree
        lbsetup = conf.lbset_dev32
        os.system(lbsetup)
        print("Config tree ready!")
        # Start with the GNOME FlashBack stuff
        cmd_list_32 = collections.deque(conf.build32_gfb_build)
        list_size_32 = len(cmd_list_32)
        for _ in range(list_size_32):
            i = cmd_list_32.popleft()
            execute = i + '()'
            exec(execute)
        # Run the specific classes
        infra.ChrootFolders("dev", "_32")
        infra.BinaryFolders("dev", "_32")
        infra.ArchitectureFiles("dev", "_32")
        # Run the Build
        print('=' * term_size.columns)
        print("INFO: Configs in place start the ISO build process")
        print("INFO: Start Live-Build Process")
        print("INFO: Current working directory" +
               current_working_directory
               )
        print('.' * term_size.columns)
        lbsetup = conf.lbset_dev32
        os.system(lbsetup)
        run_cmd = 'sudo lb build'
        current_working_directory = os.getcwd()
        os.chdir(HOME_FOLDER + FUSATO_ROOT)
        print("INFO: Current working directory" +
              current_working_directory
              )
        os.system(run_cmd)
        print("INFO: ISO build has completed successfully")
        print('.' * term_size.columns)
        print("INFO: Current working directory" +
              current_working_directory
              )
        print('=' * term_size.columns)
        finish_cleanup.make_check_sum()
        finish_cleanup.copy_iso_file_nightly_dev32()
        finish_cleanup.kill_old_iso()
        print('=' * term_size.columns)
        print("INFO: ISO is ready for usage.")
        print('=' * term_size.columns)


    def build_dev_arm(self):
        """ Builds the arm ISO GNOME FlashBack"""
        current_working_directory = os.getcwd()
        print('=' * term_size.columns)
        print("INFO: Building a devuan based arm bit ISO")
        print("INFO: Current working directory" +
               current_working_directory
               )
        print('=' * term_size.columns)
        # Set the config tree
        lbsetup = conf.lbset_devarm
        os.system(lbsetup)
        print("Config tree ready!")
        # Start with the GNOME FlashBack stuff
        cmd_list_arm = collections.deque(conf.buildarm_gfb_build)
        list_size_arm = len(cmd_list_arm)
        for _ in range(list_size_arm):
            i = cmd_list_arm.popleft()
            execute = i + '()'
            exec(execute)
        # Run the specific classes
        infra.ChrootFolders("dev", "_arm")
        infra.BinaryFolders("dev", "_arm")
        infra.ArchitectureFiles("dev", "_arm")
        # Run the Build
        print('=' * term_size.columns)
        print("INFO: Configs in place start the ISO build process")
        print("INFO: Start Live-Build Process")
        print("INFO: Current working directory" +
               current_working_directory
               )
        print('.' * term_size.columns)
        lbsetup = conf.lbset_devarm
        os.system(lbsetup)
        run_cmd = 'sudo lb build'
        current_working_directory = os.getcwd()
        os.chdir(HOME_FOLDER + FUSATO_ROOT)
        print("INFO: Current working directory" +
              current_working_directory
              )
        os.system(run_cmd)
        print("INFO: ISO build has completed successfully")
        print('.' * term_size.columns)
        print("INFO: Current working directory" +
              current_working_directory
              )
        print('=' * term_size.columns)
        finish_cleanup.make_check_sum()
        finish_cleanup.copy_iso_file_nightly_devarm()
        finish_cleanup.kill_old_iso()
        print('=' * term_size.columns)
        print("INFO: ISO is ready for usage.")
        print('=' * term_size.columns)


    def devuan_build(self):
        """
        Used to build the devuan base GNOME FlashBack ISO
        """
        if self.sarch == '_64':
            self.build_dev_64()
        elif self.sarch == '_32':
            self.build_dev_32()
        elif self.sarch == '_arm':
            self.build_dev_arm()
        else:
            print("WARNING: No active build specified")


def readybuild():
    """" Make Ready the bld structure If fusato exists remove it.
         and recreate it, otherwise just make a new folder named
         fusato.
    """
    print("INFO: Making ready the fusato build directory")
    os.chdir(HOME_FOLDER)
    if os.path.exists('fusato'):
        rm_cmd = "sudo rm -r -f fusato"
        os.system(rm_cmd)
        os.makedirs('fusato')
    else:
        os.makedirs('fusato')


class Decsions:
    """
    Aguments used to tell the application what to build
    """
    def __init__(self):
        # Set up the terminal arguments
        self.argument_parser = argparse.ArgumentParser()
        self.argument_parser.add_argument("set",
                                          help="set what build to start",
                                          type=str
                                          )
        self.argument_parser.add_argument("e",
                                          help="identify the desktop"
                                               " environment for example"
                                               " e-xfce",
                                          type=str
                                          )
        self.argument_parser.add_argument("b",
                                          help="identify the ISO to"
                                               "build for example"
                                               " b-deb64",
                                          type=str
                                          )
        self.arguments = self.argument_parser.parse_args()
        # Then determine what desktop build to look for
        if self.arguments.e == 'e-gnomefb':
            self.dgnomefb()
        elif self.arguments.e == 'e-xfce':
            self.dxfce()
        elif self.arguments.e == 'e-openbox':
            self.dopenbox()

    def dxfce(self):
        """ Arguments for the XFCE """
        if self.arguments.e == 'e-xfce':
            if self.arguments.b == 'b-deb64':
                readybuild()
                BuildXfce("deb", "_64")
            elif self.arguments.b == 'b-deb32':
                readybuild()
                BuildXfce("deb", "_32")
            elif self.arguments.b == 'b-dev64':
                readybuild()
                BuildXfce("dev", "_64")
            elif self.arguments.b == 'b-dev32':
                readybuild()
                BuildXfce("dev", "_32")
            elif self.arguments.b == 'b-debarm':
                readybuild()
                BuildXfce("deb", "_arm")
            elif self.arguments.b == 'b-devarm':
                readybuild()
                BuildXfce("dev", "_arm")
            else:
                print('You have not specified a valid '
                      'build architecture!!'
                      )

    def dgnomefb(self):
        """ Arguments for the gnomefb """
        if self.arguments.e == 'e-gnomefb':
            if self.arguments.b == 'b-deb64':
                readybuild()
                BuildGflashback("deb", "_64")
            elif self.arguments.b == 'b-deb32':
                readybuild()
                BuildGflashback("deb", "_32")
            elif self.arguments.b == 'b-dev64':
                readybuild()
                BuildGflashback("deb", "_arm")
            elif self.arguments.b == 'b-dev32':
                readybuild()
                BuildGflashback("dev", "_64")
            elif self.arguments.b == 'b-debarm':
                readybuild()
                BuildGflashback("dev", "_32")
            elif self.arguments.b == 'b-devarm':
                readybuild()
                BuildGflashback("dev", "_arm")
            else:
                print('You have not specified a valid '
                      'build architecture!!')

    def dopenbox(self):
        """ Arguments for the openbox """
        if self.arguments.e == 'e-openbox':
            if self.arguments.b == 'b-deb64':
                readybuild()
                print('run openbox builds deb64')
            elif self.arguments.b == 'b-deb32':
                readybuild()
                print('run openbox builds deb32')
            elif self.arguments.b == 'b-dev64':
                readybuild()
                print('run openbox builds dev64')
            elif self.arguments.b == 'b-dev32':
                readybuild()
                print('run openbox builds dev32')
            elif self.arguments.b == 'b-debarm':
                readybuild()
                print('run openbox builds debarm')
            elif self.arguments.b == 'b-devarm':
                readybuild()
                print('run openbox builds devarm')
            else:
                print('You have not specified a valid '
                      'build architecture!!')
        else:
            print('You have not specified a valid '
                  'desktop environment!!')


Decsions()
